Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1075)

Unified Diff: content/browser/web_contents/render_view_host_manager.cc

Issue 23530029: Support webview tag when the container extension is embedded in a webUI (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Removed unnecessary lines from document_custom_bindings Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/web_contents/render_view_host_manager.cc
diff --git a/content/browser/web_contents/render_view_host_manager.cc b/content/browser/web_contents/render_view_host_manager.cc
index 00811167c6c5f99143aafecbe2c924eab7d91b09..ad94a79c0c8b83c18c120f73133e7f992c1d6880 100644
--- a/content/browser/web_contents/render_view_host_manager.cc
+++ b/content/browser/web_contents/render_view_host_manager.cc
@@ -698,9 +698,9 @@ int RenderViewHostManager::CreateRenderView(
bool RenderViewHostManager::InitRenderView(RenderViewHost* render_view_host,
int opener_route_id) {
- // If the pending navigation is to a WebUI, tell the RenderView about any
- // bindings it will need enabled.
- if (pending_web_ui())
+ // If the pending navigation is to a WebUI and the RenderView is not in a
+ // guest process, tell the RenderView about any bindings it will need enabled.
+ if (pending_web_ui() && !render_view_host->GetProcess()->IsGuest())
Charlie Reis 2013/09/13 21:17:24 Is this independent of the rest of the CL? Maybe
guohui 2013/09/16 22:27:02 yes it is, though without other changes in this CL
Charlie Reis 2013/09/18 17:42:23 It's still a useful defense-in-depth check, so I t
guohui 2013/09/19 13:48:41 Done.
render_view_host->AllowBindings(pending_web_ui()->GetBindings());
return delegate_->CreateRenderViewForRenderManager(render_view_host,

Powered by Google App Engine
This is Rietveld 408576698